==> ssp-center-api-0.6.78-20200318.095000-6-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqActivityDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/21
 */
public class ReqActivityDto extends BaseQueryDto {

    private static final long          serialVersionUID = -2958741430564581249L;

    private Long                       plantId;                                 //推广计划ID
    private Long                       id;                                      // 活动ID
    private Integer                    type;                                    // 活动类型
    private String                     title;                                   // 活动名称
    private String                     planTitle;                               //推广计划标题
    private String                     description;                             //推广计划描述
    private List<Long>                 msIdList;                                // 规格列表
    private List<Long>                 idList;                                  // 活动ID列表
    private List<RspMsContentGroupDto> msContentList;                           // 素材内容
    private List<SlotMaterial> slotMaterial;//广告位定制素材
    private Integer                    source;                                  // 0-兑吧活动 1-推啊活动 2-流量引导页
    private Integer                    isDirectMedia;                           //是否定向到媒体 0不定向，1定向
    private String                     subType;                                 //活动皮肤类型
    private Integer                    cronType;                                //0非周期活动，1按星期，2按月
    private Long slotId;//广告位id
    private Integer activityDefType; //1-普通活动 2-自定义活动 3-直投活动 4-原生化活动
    private Integer                    isEnc; // 是否支持增值 0-否 1-是

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<Long> getMsIdList() {
        return msIdList;
    }

    public void setMsIdList(List<Long> msIdList) {
        this.msIdList = msIdList;
    }

    public List<Long> getIdList() {
        return idList;
    }

    public void setIdList(List<Long> idList) {
        this.idList = idList;
    }

    public List<RspMsContentGroupDto> getMsContentList() {
        return msContentList;
    }

    public void setMsContentList(List<RspMsContentGroupDto> msContentList) {
        this.msContentList = msContentList;
    }

    
    public Integer getSource() {
        return source;
    }

    
    public void setSource(Integer source) {
        this.source = source;
    }

    public String getPlanTitle() {
        return planTitle;
    }

    public void setPlanTitle(String planTitle) {
        this.planTitle = planTitle;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


    public Long getPlantId() {
        return plantId;
    }

    public void setPlantId(Long plantId) {
        this.plantId = plantId;
    }

    public Integer getIsDirectMedia() {
        return isDirectMedia;
    }

    public void setIsDirectMedia(Integer isDirectMedia) {
        this.isDirectMedia = isDirectMedia;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getCronType() {
        return cronType;
    }

    public void setCronType(Integer cronType) {
        this.cronType = cronType;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public List<SlotMaterial> getSlotMaterial() {
		return slotMaterial;
	}

	public void setSlotMaterial(List<SlotMaterial> slotMaterial) {
		this.slotMaterial = slotMaterial;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

    public Integer getActivityDefType() {
        return activityDefType;
    }

    public void setActivityDefType(final Integer activityDefType) {
        this.activityDefType = activityDefType;
    }
}

==> ssp-center-api-1.0.98-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/ReqActivityDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import org.apache.commons.lang.builder.ToStringBuilder;

import java.util.List;

/**
 * @author xuyenan
 * @createTime 2016/12/21
 */
public class ReqActivityDto extends BaseQueryDto {

    private static final long          serialVersionUID = -2958741430564581249L;

    private Long                       plantId;                                 //推广计划ID
    private Long                       id;                                      // 活动ID
    private Integer                    type;                                    // 活动类型
    private String                     title;                                   // 活动名称
    private String                     planTitle;                               //推广计划标题
    private String                     description;                             //推广计划描述
    private List<Long>                 msIdList;                                // 规格列表
    private List<Long>                 idList;                                  // 活动ID列表
    private List<RspMsContentGroupDto> msContentList;                           // 素材内容
    private List<SlotMaterial> slotMaterial;//广告位定制素材
    private Integer                    source;                                  // 0-兑吧活动 1-推啊活动 2-流量引导页
    private Integer                    isDirectMedia;                           //是否定向到媒体 0不定向，1定向
    private String                     subType;                                 //活动皮肤类型
    private Integer                    cronType;                                //0非周期活动，1按星期，2按月
    private Long slotId;//广告位id
    private Integer activityDefType; //1-普通活动 2-自定义活动 3-直投活动 4-原生化活动
    private Integer                    isEnc; // 是否支持增值 0-否 1-是

    private List<Long> tagIds;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public Integer getType() {
        return type;
    }

    public void setType(Integer type) {
        this.type = type;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public List<Long> getMsIdList() {
        return msIdList;
    }

    public void setMsIdList(List<Long> msIdList) {
        this.msIdList = msIdList;
    }

    public List<Long> getIdList() {
        return idList;
    }

    public void setIdList(List<Long> idList) {
        this.idList = idList;
    }

    public List<RspMsContentGroupDto> getMsContentList() {
        return msContentList;
    }

    public void setMsContentList(List<RspMsContentGroupDto> msContentList) {
        this.msContentList = msContentList;
    }

    
    public Integer getSource() {
        return source;
    }

    
    public void setSource(Integer source) {
        this.source = source;
    }

    public String getPlanTitle() {
        return planTitle;
    }

    public void setPlanTitle(String planTitle) {
        this.planTitle = planTitle;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }


    public Long getPlantId() {
        return plantId;
    }

    public void setPlantId(Long plantId) {
        this.plantId = plantId;
    }

    public Integer getIsDirectMedia() {
        return isDirectMedia;
    }

    public void setIsDirectMedia(Integer isDirectMedia) {
        this.isDirectMedia = isDirectMedia;
    }

    public String getSubType() {
        return subType;
    }

    public void setSubType(String subType) {
        this.subType = subType;
    }

    public Integer getCronType() {
        return cronType;
    }

    public void setCronType(Integer cronType) {
        this.cronType = cronType;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

	public List<SlotMaterial> getSlotMaterial() {
		return slotMaterial;
	}

	public void setSlotMaterial(List<SlotMaterial> slotMaterial) {
		this.slotMaterial = slotMaterial;
	}

	public Long getSlotId() {
		return slotId;
	}

	public void setSlotId(Long slotId) {
		this.slotId = slotId;
	}

    public Integer getActivityDefType() {
        return activityDefType;
    }

    public void setActivityDefType(final Integer activityDefType) {
        this.activityDefType = activityDefType;
    }

    public List<Long> getTagIds() {
        return tagIds;
    }

    public void setTagIds(List<Long> tagIds) {
        this.tagIds = tagIds;
    }
}
